Struct webview2_com::CoTaskMemRef
source · pub struct CoTaskMemRef<'a>(_, _);Expand description
Constant guard object tied to the lifetime of the CoTaskMemPWSTR so that it
is safe to dereference the PCWSTR as long as both are still in scope.
Implementations