Crate webview2_com
source ·Modules
Structs
Implementation of
ICoreWebView2AddScriptToExecuteOnDocumentCreatedCompletedHandler.Implementation of
ICoreWebView2BasicAuthenticationRequestedEventHandler.Implementation of
ICoreWebView2CallDevToolsProtocolMethodCompletedHandler.Implementation of
ICoreWebView2CapturePreviewCompletedHandler.Implementation of
ICoreWebView2ClearServerCertificateErrorActionsCompletedHandler.Implementation of
ICoreWebView2ClientCertificateRequestedEventHandler.Mutable guard object tied to the lifetime of the
CoTaskMemPWSTR so that it
is safe to dereference the PWSTR as long as both are still in scope.RAII holder for a
PWSTR which is allocated with Com::CoTaskMemAlloc and freed
with Com::CoTaskMemFree when dropped.Constant guard object tied to the lifetime of the
CoTaskMemPWSTR so that it
is safe to dereference the PCWSTR as long as both are still in scope.Implementation of
ICoreWebView2ContainsFullScreenElementChangedEventHandler.Implementation of
ICoreWebView2ContentLoadingEventHandler.Implementation of
ICoreWebView2CreateCoreWebView2CompositionControllerCompletedHandler.Implementation of
ICoreWebView2CreateCoreWebView2ControllerCompletedHandler.Implementation of
ICoreWebView2CreateCoreWebView2EnvironmentCompletedHandler.Implementation of
ICoreWebView2CursorChangedEventHandler.Implementation of
ICoreWebView2CustomItemSelectedEventHandler.Implementation of
ICoreWebView2DOMContentLoadedEventHandler.Implementation of
ICoreWebView2DevToolsProtocolEventReceivedEventHandler.Implementation of
ICoreWebView2DownloadStartingEventHandler.Implementation of
ICoreWebView2EstimatedEndTimeChangedEventHandler.Implementation of
ICoreWebView2ExecuteScriptCompletedHandler.Implementation of
ICoreWebView2FaviconChangedEventHandler.Implementation of
ICoreWebView2FocusChangedEventHandler.Implementation of
ICoreWebView2FrameContentLoadingEventHandler.Implementation of
ICoreWebView2FrameCreatedEventHandler.Implementation of
ICoreWebView2FrameDestroyedEventHandler.Implementation of
ICoreWebView2FrameNameChangedEventHandler.Implementation of
ICoreWebView2FrameNavigationCompletedEventHandler.Implementation of
ICoreWebView2FrameNavigationStartingEventHandler.Implementation of
ICoreWebView2FramePermissionRequestedEventHandler.Implementation of
ICoreWebView2FrameWebMessageReceivedEventHandler.Implementation of
ICoreWebView2GetCookiesCompletedHandler.Implementation of
ICoreWebView2GetFaviconCompletedHandler.Implementation of
ICoreWebView2HistoryChangedEventHandler.Implementation of
ICoreWebView2IsDefaultDownloadDialogOpenChangedEventHandler.Implementation of
ICoreWebView2IsDocumentPlayingAudioChangedEventHandler.Implementation of
ICoreWebView2IsMutedChangedEventHandler.Implementation of
ICoreWebView2MoveFocusRequestedEventHandler.Implementation of
ICoreWebView2NavigationCompletedEventHandler.Implementation of
ICoreWebView2NavigationStartingEventHandler.Implementation of
ICoreWebView2NewBrowserVersionAvailableEventHandler.Implementation of
ICoreWebView2NewWindowRequestedEventHandler.Implementation of
ICoreWebView2PermissionRequestedEventHandler.Implementation of
ICoreWebView2PrintCompletedHandler.Implementation of
ICoreWebView2PrintToPdfCompletedHandler.Implementation of
ICoreWebView2ProcessFailedEventHandler.Implementation of
ICoreWebView2ProcessInfosChangedEventHandler.Implementation of
ICoreWebView2RasterizationScaleChangedEventHandler.Implementation of
ICoreWebView2ScriptDialogOpeningEventHandler.Implementation of
ICoreWebView2ServerCertificateErrorDetectedEventHandler.Implementation of
ICoreWebView2SourceChangedEventHandler.Implementation of
ICoreWebView2StateChangedEventHandler.Implementation of
ICoreWebView2TrySuspendCompletedHandler.Implementation of
ICoreWebView2WebMessageReceivedEventHandler.Implementation of
ICoreWebView2WebResourceResponseReceivedEventHandler.Implementation of
ICoreWebView2WebResourceResponseViewGetContentCompletedHandler.Implementation of
ICoreWebView2ZoomFactorChangedEventHandler.Enums
Traits
Functions
Copy a
PWSTR allocated with Com::CoTaskMemAlloc from an input param to a String
and free the original buffer with Com::CoTaskMemFree.The WebView2 threading model runs everything on the UI thread, including callbacks which it triggers
with
PostMessage, and we’re using this here because it’s waiting for some async operations in WebView2
to finish before starting the main message loop. As long as there are no pending results in rx, it
will pump Window messages and check for a result after each message is dispatched.Type Definitions
Generic closure signature for
completed_callback.Generic closure signature for
event_callback.